<template>
  <div class="userwrap">
    <div class="title">
      {{$t('userSelectBox')}}
      <!--编辑流程审批人按钮-->
    </div>
    <div class="search">
      <form class="search-block" action="javascript:void 0">
        <i class="fa fa-search local"></i>
        <input 
          type="search" 
          class="form_search" 
          v-model="keyWord" 
          @keyup.13="search"
          :placeholder="$t('search')"
        >
      </form>
    </div>

    <!--用户列表-->
    <div class="list-wrap position-box"
      style="border:1px solid white;overflow:auto"
      :style="{height: pendingContentH + 'px'}"
      ref="pendingwrapper"
    >
      <vue-better-scroll class="wrapper"
        ref="scroll"
        :scrollbar="scrollbarObj"
        :pullUpLoad="pullUpLoadObj"
        :startY="parseInt(startY)"
        @pulling-up="onPullingUp">
        <div class="user-list" v-for="(item, index) in approverList" :key="index">
          <!--当不是自由流程时-->
          <div class="list-check">
            <label class="mint-checklist-label pending-radio">
              <span class="mint-checkbox">
                <input 
                  type="checkbox" 
                  class="mint-checkbox-input"   
                  v-model="checkVal" 
                  :value="item.id" 
                  @change="handleSelectionChange($event, item)"
                />
                <span class="mint-checkbox-core"></span>
              </span>
            </label>
          </div>

          <div class="photo">
            <img src="../assets/images/face.jpg">
          </div>
          <div class="list-info">
            <span>
              {{item.name}}
            </span>
            <span>
              {{item.dept}}
            </span>
          </div>
          
        </div>
      </vue-better-scroll>
    </div>
    <div class="bottom-btns">
      <div class="selected">{{$t('select_dept')}}:{{checkVal.length}}/{{row_count}}
        <span style="margin-left:3px;" @click="showSelectedUser">
          <img src="../assets/images/Arrow_D.png" />
        </span>
      </div>
      <mt-button class="btn" type="primary" size="small" @click="onOK">{{$t('verify')}}</mt-button>
    </div>
  </div>
</template>

<script>
import VueBetterScroll from "vue2-better-scroll";
import { Toast } from 'mint-ui';
import { Indicator } from "mint-ui";
export default {
  props: [
    "act", 
    "openParams", 
    "buildFormData", 
    "approvers",
    "newUserList"
  ],
  components: { VueBetterScroll },
  watch: {
    newUserList() {
      this.newSelectData();
    },
  },
  data: function() {
    return {
      checkVal:[],
      value:'',
      selectRow:[],
      approverList:[],
      row_count:0,
      keyWord:'',

      // 这个配置可以开启滚动条，默认为 false。当设置为 true 或者是一个 Object 的时候，都会开启滚动条，默认是会 fade 的
      scrollbarObj: {
        fade: true
      },
      // 这个配置用于做下拉刷新功能，默认为 false。当设置为 true 或者是一个 Object 的时候，可以开启下拉刷新，可以配置顶部下拉的距离（threshold） 来决定刷新时机以及回弹停留的距离（stop）
      pullDownRefreshObj: {
        threshold: 90,
        stop: 40,
        txt: this.$t('noMoreData')
      
      },
      // 这个配置用于做上拉加载功能，默认为 false。当设置为 true 或者是一个 Object 的时候，可以开启上拉加载，可以配置离底部距离阈值（threshold）来决定开始加载的时机
      pullUpLoadObj: {
        threshold: 0,
        stop: 40,
        txt: {
          more: this.$t('loadMore'),
          noMore: this.$t('noMoreData')
        }
      },
      startY: 100, // 纵轴方向初始化位置
      scrollToX: 0,
      scrollToY: 0,
      scrollToTime: 700,
      items: [],
      pendingContentH:'',
      auditorsList:[],
    };
  },
  
  mounted() {
   this.getData();
   this.setOriginalApprover();
   this.$nextTick(function() {
      this.pendingContentH =
        document.documentElement.clientHeight -
        this.$refs.pendingwrapper.getBoundingClientRect().top-100;
    });
  },
  methods: {
     newSelectData() {
      let data = JSON.parse(JSON.stringify(this.newUserList));
      this.checkVal = [];
      this.auditorsList = data;
      data.forEach(el => {
        this.checkVal.push(el.id);
      });
      this.$forceUpdate() //重新渲染数据
    },
    handleSelectionChange(ev, item) {
      let val = this.checkVal;
      if(ev.target.checked && val.length > 0) {
        for(let i=0; i<val.length; i++) {
          if(val[i] == item.id) {
            this.auditorsList.push({id:item.id, name:item.name, userCode:item.loginNo})
          }
        }
      }else {
        for(let j=0; j<this.auditorsList.length; j++) {
          if(item.id == this.auditorsList[j].id) {
            this.auditorsList.splice(j,1);
          }
        }
      }
    },

    showSelectedUser(){
      let value = "LIST"
      let subflowRow = []; //子流程才有这个数据
      let data = JSON.parse(JSON.stringify(this.auditorsList)); 
      let isApproverWork = true;
      this.$emit("showUser", data, value, this.row_count, '', subflowRow, isApproverWork); //调用父组件showSelectedUser()方法;
    },

    //回显原审批人
    setOriginalApprover() {
      if(this.approvers) {
        this.approvers.forEach(items => {
          if(items.nodes.length > 0) {
            items.nodes.forEach(item => {
              this.auditorsList = item.auditors;
              item.auditors.forEach(el => {
                this.checkVal.push(el.id);
              });
            });
          }
        });
      }
    },
    getData(){
      this.getApproverList().then((response) => {
        this.approverList = response.data.datas;
        this.row_count = response.data.rowCount;
      }).then(()=> {
      }); 
    },

    getApproverList(keyWord) {
      return new Promise(resolve => { 
        let lastPage = Math.floor(this.approverList.length / 10) + 1;
        let pageSize = 10;
        let keyword = keyWord?keyWord:'';
        this.$api.getSearch(encodeURIComponent(keyword), lastPage, pageSize, {
          onSucess: response => {
            let data = response.data;
            resolve(data);
          }
        })
        
      });
    },

    onPullingUp() {
      // 模拟上拉 加载更多数据
      if(this.approverList.length < this.row_count) {
        this.getApproverList(this.keyWord).then((response) => {
          this.approverList = this.approverList.concat(response.data.datas);
          this.$refs.scroll.forceUpdate(true);
        })
      }else {
        this.$refs.scroll.forceUpdate(false);
      }
    },

    search() {
      this.approverList = [];
      this.getApproverList(this.keyWord).then((response) => {
        this.approverList = response.data.datas;
        this.row_count = response.data.rowCount;
        if(this.approverList.length < response.data.rowCount) {
          this.$refs.scroll.forceUpdate(true);
        }else {
          this.$refs.scroll.forceUpdate(false);
        }
      })
    },

    onOK(){
      if(this.checkVal && this.checkVal.length > 0) {
        Indicator.open({
          text: this.$t('submitting'),
          spinnerType: "fading-circle"
        });
        let appId = this.$root.appid,
          docId = this.buildFormData.id;
        let flowData = {
          auditorList: this.checkVal,
        }
        this.$api.approversWorkflow(appId, docId, flowData, {
          onSucess: response => {
            Indicator.close();
            let status;
            if(response.data.errcode==0) {
              status = 'SUCCESS';
              this.$emit("closePopup",status)
              Toast({
                  message: response.data.data,
                  iconClass: 'fa fa-check fa-2x'
                });
            }else if(response.data.errcode==4001){
              status = 'ERROR';
              this.$emit("closePopup",status)
              Toast({
                message: response.data.errmsg,
                iconClass: 'fa fa-close fa-2x'
              });
            }
          }
        }) 
      }else {
        status = 'ERROR';
        this.$emit("closePopup",status)
      }
    },
  }
};
</script>